pub fn add(command: &AddCommand, stats: &mut Stats) -> ExitCodeExpand description
Creates the worktree, cloning what it can and letting git finish the job.
pub fn add(command: &AddCommand, stats: &mut Stats) -> ExitCodeCreates the worktree, cloning what it can and letting git finish the job.