Structs
- AddCommand
- A
git worktree addinvocation parsed well enough to consider accelerating.
Enums
- Invocation
- What the command line asks the tool to do.
Functions
- parse
- Parses the argument tail the binary was invoked with.
git worktree add invocation parsed well enough to consider accelerating.